import { IDisposable } from '@lumino/disposable';
import { BasicMouseHandler, DataGrid, DataModel, ResizeHandle } from 'tde-datagrid';
import { Signal } from '@lumino/signaling';
import { IBoundingRegion } from './drag';
export declare class RichMouseHandler extends BasicMouseHandler {
    private _moveLine;
    private _currentHoverRegion;
    constructor(options: RichMouseHandler.IOptions);
    get hoverSignal(): Signal<this, 'ghost-row' | 'ghost-column' | null>;
    get mouseUpSignal(): Signal<this, DataGrid.HitTestResult>;
    /**
     * Computes the bounding region for the grid (provides boundaries for the shadow/line when moving)
     * @param region The current region
     * @param shadowRegion The indexes for the rows/columns of the shadow region
     */
    computeGridBoundingRegion(): IBoundingRegion;
    /**
     * @override
     * Returns the proper resize cursor type based on the region clicked
     * Calls cursorByRegion if no resize cursor is correct
     * @param area The current area "top" | "left" | "right" | "bottom" | "none"
     */
    cursorForHandle(area: ResizeHandle): string;
    /**
     * Called from the cursorForHandle function to enable grab cursor by region
     * @param region The current region in the model
     * @param row The current row
     * @param column The current column
     */
    cursorByRegion(region: DataModel.CellRegion | 'void', row: number, column: number): string;
    /**
     * @override
     * @param grid
     * @param event
     */
    onMouseHover(grid: DataGrid, event: MouseEvent): void;
    /**
     * @override
     * Handle the mouse down event for the data grid.
     * @param grid - The data grid of interest.
     * @param event - The mouse down event of interest.
     */
    onMouseDown(grid: DataGrid, event: MouseEvent): void;
    /**
     * @override
     */
    release(): void;
    /**
     * Creates the shadow/line on the row/column that was grabbed
     */
    handleGrabbing(): void;
    getRowOrColumnSection(region: DataModel.CellRegion | 'void', index: number): RichMouseHandler.IRegion;
    /**
     * @override
     * Handle the mouse move event for the data grid.
     * @param grid - The data grid of interest.
     * @param event - The mouse move event of interest.
     */
    onMouseMove(grid: DataGrid, event: MouseEvent): void;
    /**
     * Moves the line based on the position of the cursor and shadow
     * @param grid
     * @param event
     */
    updateLinePosition(event: MouseEvent): void;
    /**
     * @override
     * @param grid
     * @param event
     */
    onMouseUp(grid: DataGrid, event: MouseEvent): void;
    /**
     * Handle the context menu event for the data grid.
     * @param grid - The data grid of interest.
     * @param event - The context menu event of interest.
     */
    onContextMenu(grid: DataGrid, event: MouseEvent): void;
    /**
     * Handles a double click event
     */
    onMouseDoubleClick(grid: DataGrid, event: MouseEvent): void;
    private _grid;
    private _event;
    private _cursor;
    private _moveData;
    private _mouseUpSignal;
    private _ghostHoverSignal;
    private _selectionIndex;
}
export declare type MoveData = {
    /**
     * The descriminated type for the data.
     */
    readonly type: 'move';
    /**
     * The region which holds the section being moved.
     */
    readonly region: DataModel.CellRegion;
    readonly row: number;
    readonly column: number;
    readonly override: IDisposable;
    readonly localX: number;
    readonly localY: number;
    readonly timeout: number;
};
export declare namespace RichMouseHandler {
    interface IOptions {
        grid: DataGrid;
    }
    /**
     * The coordinates for a rectangular region.
     */
    interface IRegion {
        topSide: number;
        bottomSide: number;
        leftSide: number;
        rightSide: number;
    }
}
